NLSL: dtime.c File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions
dtime.c File Reference
`#include <time.h>`
`#include <sys/times.h>`
`#include "fortrancall.h"`
Include dependency graph for dtime.c:

Go to the source code of this file.

## Functions
float FORTRAN() | dtime (float *dt)

## Function Documentation

float FORTRAN() dtime | ( | float * | dt | ) |

Definition at line 24 of file dtime.c.